@@ -1,19 +1,19 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2001 Havoc Pennington, 2011 Andreas Rönnquist
+ *	Copyright (C) 2001 Havoc Pennington, 2011-2012 Andreas Rönnquist
  *
- *	devilspie2 is free software: you can redistribute it and/or 
- *	modify it under the terms of the GNU General Public License as published 
+ *	devilspie2 is free software: you can redistribute it and/or
+ *	modify it under the terms of the GNU General Public License as published
  *	by the Free Software Foundation, either version 3 of the License, or
  *	(at your option) any later version.
- * 
+ *
  *	devilspie2 is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *	GNU General Public License for more details.
- * 
+ *
  *	You should have received a copy of the GNU General Public License
- *	along with devilspie2.  
+ *	along with devilspie2.
  *	If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -22,6 +22,14 @@
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
 
+#include <locale.h>
+
+#include <libintl.h>
+#define _(String) gettext (String)
+#define gettext_noop(String) String
+#define N_(String) gettext_noop (String)
+
+
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
 
@@ -41,23 +49,20 @@ Atom my_wnck_atom_get(const char *atom_name)
 
 	g_return_val_if_fail (atom_name != NULL, None);
 
-	if (!atom_hash)
-	{
+	if (!atom_hash) {
 		atom_hash = g_hash_table_new (g_str_hash, g_str_equal);
 		reverse_atom_hash = g_hash_table_new (NULL, NULL);
 	}
-      
+
 	retval = GPOINTER_TO_UINT (g_hash_table_lookup (atom_hash, atom_name));
-	if (!retval)
-	{
+	if (!retval) {
 		retval = XInternAtom (gdk_x11_get_default_xdisplay(), atom_name, FALSE);
 
-		if (retval != None)
-		{
+		if (retval != None) {
 			char *name_copy;
 
 			name_copy = g_strdup (atom_name);
-          
+
 			g_hash_table_insert (atom_hash,
 										name_copy,
 										GUINT_TO_POINTER (retval));
@@ -82,7 +87,7 @@ void my_wnck_change_state(Screen *screen, Window xwindow,
 
 #define _NET_WM_STATE_REMOVE        0    /* remove/unset property */
 #define _NET_WM_STATE_ADD           1    /* add/set property */
-#define _NET_WM_STATE_TOGGLE        2    /* toggle property  */  
+#define _NET_WM_STATE_TOGGLE        2    /* toggle property  */
 
 	xev.xclient.type = ClientMessage;
 	xev.xclient.serial = 0;
@@ -142,8 +147,8 @@ static void set_decorations(WnckWindow *window, gboolean decorate)
 
 	/* Set Motif hints, most window managers handle these */
 	XChangeProperty(gdk_x11_get_default_xdisplay(), wnck_window_get_xid (window),
-						my_wnck_atom_get ("_MOTIF_WM_HINTS"), 
-						my_wnck_atom_get ("_MOTIF_WM_HINTS"), 32, PropModeReplace, 
+						my_wnck_atom_get ("_MOTIF_WM_HINTS"),
+						my_wnck_atom_get ("_MOTIF_WM_HINTS"), 32, PropModeReplace,
 						(unsigned char *)&hints, PROP_MOTIF_WM_HINTS_ELEMENTS);
 
 	/* Apart from OpenBox, which doesn't respect it changing after mapping.
@@ -161,14 +166,14 @@ static void set_decorations(WnckWindow *window, gboolean decorate)
 gboolean decorate_window(WnckWindow *window)
 {
 	my_wnck_error_trap_push();
-	
+
 	set_decorations(window,TRUE);
-	
+
 	if (my_wnck_error_trap_pop()) {
-		g_printerr("decorate_window Failed!\n");
+		g_printerr("decorate_window %s\n",_("Failed!"));
 		return FALSE;
 	}
-	
+
 	return TRUE;
 }
 
@@ -179,14 +184,14 @@ gboolean decorate_window(WnckWindow *window)
 gboolean undecorate_window(WnckWindow *window)
 {
 	my_wnck_error_trap_push();
-	
+
 	set_decorations(window,FALSE);
-	
+
 	if (my_wnck_error_trap_pop()) {
-		g_printerr("decorate_window Failed!\n");
+		g_printerr("decorate_window %s\n", _("Failed!"));
 		return FALSE;
 	}
-	
+
 	return TRUE;
 }
 
